@@ -4,7 +4,7 @@
 package Lingua::Interset::Tagset::LT::Multext;
 use strict;
 use warnings;
-our $VERSION = '3.013';
+our $VERSION = '3.014';
 
 use utf8;
 use open ':utf8';
@@ -81,20 +81,20 @@ sub _create_atoms
             'poss' => { '@' => 'g' }
         }
     );
-    # ADJECTIVE FORMATION ####################
+    # DEFINITENESS ####################
     # In Lithuanian, this feature is presented as "pronominal suffix yes or no?"
-    # Hence the short form (more frequent) has 'n', the long form 'y'.
-    $atoms->{adjform} = $self->create_atom
+    # Hence the short form (more frequent, indefinite) has 'n', the long form (pronominal, definite) 'y'.
+    $atoms->{definite} = $self->create_atom
     (
-        'surfeature' => 'adjform',
+        'surfeature' => 'definite',
         'decode_map' =>
         {
-            # Nominal, short form of adjective.
+            # Nominal, short form of adjective. (NOTE: we are now reclassifying this as the indefinite form, see the feature of definiteness.)
             # examples: lietuviškas
-            'n' => ['variant' => 'short'],
-            # Pronominal, long form of adjective.
+            'n' => ['definite' => 'ind'],
+            # Pronominal, long form of adjective. (NOTE: we are now reclassifying this as the definite form, see the feature of definiteness.)
             # examples: lietuviškasis
-            'y' => ['variant' => 'long']
+            'y' => ['definite' => 'def']
         },
         'encode_map' =>
         {
@@ -107,9 +107,9 @@ sub _create_atoms
                                                                                    'gdv'  => '-',
                                                                                    'inf'  => '-',
                                                                                    'fin'  => '-',
-                                                                                   '@'    => { 'variant' => { 'short' => 'n',
-                                                                                                              'long'  => 'y',
-                                                                                                              '@'     => 'n' }}}}}}}
+                                                                                   '@'    => { 'definite' => { 'ind' => 'n',
+                                                                                                               'def' => 'y',
+                                                                                                               '@'   => 'n' }}}}}}}
         }
     );
     # CONJTYPE ####################
@@ -329,18 +329,21 @@ sub _create_atoms
 
 #------------------------------------------------------------------------------
 # Creates a map that tells for each surface part of speech which features are
-# relevant and in what order they appear.
+# relevant and in what order they appear. The MULTEXT-EAST website does not
+# document Lithuanian but the annotation manual supplied with v2.2 of the
+# ALKSNIS treebank (http://hdl.handle.net/20.500.11821/20) has some documenta-
+# tion (in Lithuanian only).
 #------------------------------------------------------------------------------
 sub _create_feature_map
 {
     my $self = shift;
     my %features =
     (
-        'N' => ['pos', 'nountype', 'gender', 'number', 'case', 'adjform', 'nametype'], # I do not understand the meaning of the last two features. The penultimate feature is almost always 'n', sometimes 'y' or 'a' ('a' is probably a typo). It could correspond to the form of adjectives, for nouns that are derived from adjectives. It seems to be a lexical feature of nouns. The last feature is often '-', sometimes 'g', 's' or 'f', and it occurs almost exclusively with proper nouns. My guess: 'f' is a personal first name; 's' is a surname; 'g' is a geographical name.
-        'A' => ['pos', 'adjtype', 'degree', 'gender', 'number', 'case', 'adjform'], # The last feature is 'n' or 'y'. It seems to distinguish the nominal form 'n' from the pronominal form 'y'.
-        'P' => ['pos', 'prontype', 'gender', 'number', 'case', 'adjform'], # They do not distinguish pronoun types. Everything is Pg*. They also do not distinguish person. The last feature is 'n', 'y' or '-'.
-        'M' => ['pos', 'numtype', 'gender', 'number', 'case', 'numform', 'adjform'], # The last feature is 'n', 'y' or '-'.
-        'V' => ['pos', 'verbtype', 'verbform', 'tense', 'person', 'number', 'gender', 'voice', 'polarity', 'adjform', 'case', 'reflex', 'mood', undef], # Verb type is always 'g'. Last feature is 'p' for participles, '-' otherwise. But participles are already identified by 'p' in the third position.
+        'N' => ['pos', 'nountype', 'gender', 'number', 'case', 'reflex', 'nametype'], # The last feature is often '-', sometimes 'g', 's' or 'f', and it occurs almost exclusively with proper nouns. My guess: 'f' is a personal first name; 's' is a surname; 'g' is a geographical name.
+        'A' => ['pos', 'adjtype', 'degree', 'gender', 'number', 'case', 'definite'], # The last feature distinguishes the nominal, indefinite form 'n' from the pronominal, definite form 'y'.
+        'P' => ['pos', 'prontype', 'gender', 'number', 'case', 'definite'], # They do not distinguish pronoun types. Everything is Pg*. They also do not distinguish person. The last feature is 'n', 'y' or '-'.
+        'M' => ['pos', 'numtype', 'gender', 'number', 'case', 'numform', 'definite'], # The last feature is 'n', 'y' or '-'.
+        'V' => ['pos', 'verbtype', 'verbform', 'tense', 'person', 'number', 'gender', 'voice', 'polarity', 'definite', 'case', 'reflex', 'mood', 'degree'], # Verb type is always 'g'. Last feature is 'p' for participles, '-' otherwise. But participles are already identified by 'p' in the third position. According to the documentation of the ALKSNIS treebank, the feature may mark the positive degree.
         'R' => ['pos', 'adverb_type', 'degree'],
         'S' => ['pos', 'adpostype', 'case'],
         'C' => ['pos', 'conjtype'], # just Cg
@@ -1052,7 +1055,7 @@ Lingua::Interset::Tagset::LT::Multext - Driver for the Lithuanian Multext-EAST-l
 
 =head1 VERSION
 
-version 3.013
+version 3.014
 
 =head1 SYNOPSIS
 
